@@ -1,5 +1,6 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2002 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2002, 2004
+   Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -87,7 +88,7 @@ private:
   unsigned ligatures;
   font_kern_list **kern_hash_table;
   int space_width;
-  short *ch_index;
+  int *ch_index;
   int nindices;
   font_char_metric *ch;
   int ch_used;
