@@ -31,14 +31,15 @@ extern "C" {
   const char *if_to_a(int, int);
 }
 
-/* stdio.h on IRIX, OSF/1, emx, and UWIN include getopt.h */
+/* stdio.h on IRIX, OSF/1, emx, UWIN, and MinGW include getopt.h */
 /* unistd.h on CYGWIN includes getopt.h */
 
 #if !(defined(__sgi) \
       || (defined(__osf__) && defined(__alpha)) \
       || defined(_UWIN) \
       || defined(__EMX__) \
-      || defined(__CYGWIN__))
+      || defined(__CYGWIN__) \
+      || defined(__MINGW32__))
 #include <groff-getopt.h>
 #else
 #include <getopt.h>
@@ -59,13 +60,21 @@ int is_prime(unsigned);
 #include <strings.h>
 #endif
 
-/* HP-UX 10.20 doesn't declare snprintf() */
-#if !defined(HAVE_SNPRINTF) || defined(NEED_DECLARATION_SNPRINTF)
 #include <stdarg.h>
-extern "C" {
-  int snprintf(char *, size_t, const char *, /*args*/ ...);
-  int vsnprintf(char *, size_t, const char *, va_list);
-}
+
+/* HP-UX 10.20 and LynxOS 4.0.0 don't declare snprintf() */
+#if !defined(HAVE_SNPRINTF) || defined(NEED_DECLARATION_SNPRINTF)
+extern "C" { int snprintf(char *, size_t, const char *, /*args*/ ...); }
+#endif
+
+/* LynxOS 4.0.0 has snprintf() but no vsnprintf() */
+#if !defined(HAVE_VSNPRINTF) || defined(NEED_DECLARATION_VSNPRINTF)
+extern "C" { int vsnprintf(char *, size_t, const char *, va_list); }
+#endif
+
+/* LynxOS 4.0.0 doesn't declare vfprintf() */
+#ifdef NEED_DECLARATION_VFPRINTF
+extern "C" { int vfprintf(FILE *, const char *, va_list); }
 #endif
 
 #ifndef HAVE_MKSTEMP
@@ -102,29 +111,21 @@ inline int invalid_input_char(int c)
 
 #ifdef HAVE_STRCASECMP
 #ifdef NEED_DECLARATION_STRCASECMP
-extern "C" {
-  // Ultrix4.3's string.h fails to declare this.
-  int strcasecmp(const char *, const char *);
-}
+// Ultrix4.3's string.h fails to declare this.
+extern "C" { int strcasecmp(const char *, const char *); }
 #endif /* NEED_DECLARATION_STRCASECMP */
 #else /* not HAVE_STRCASECMP */
-extern "C" {
-  int strcasecmp(const char *, const char *);
-}
+extern "C" { int strcasecmp(const char *, const char *); }
 #endif /* HAVE_STRCASECMP */
 
 #if !defined(_AIX) && !defined(sinix) && !defined(__sinix__)
 #ifdef HAVE_STRNCASECMP
 #ifdef NEED_DECLARATION_STRNCASECMP
-extern "C" {
-  // SunOS's string.h fails to declare this.
-  int strncasecmp(const char *, const char *, int);
-}
+// SunOS's string.h fails to declare this.
+extern "C" { int strncasecmp(const char *, const char *, int); }
 #endif /* NEED_DECLARATION_STRNCASECMP */
 #else /* not HAVE_STRNCASECMP */
-extern "C" {
-  int strncasecmp(const char *, const char *, size_t);
-}
+extern "C" { int strncasecmp(const char *, const char *, size_t); }
 #endif /* HAVE_STRNCASECMP */
 #endif /* !_AIX && !sinix && !__sinix__ */
 
