@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2003
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2003, 2004
    Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
@@ -128,14 +128,14 @@ void prints(const string &s)
 
 struct horizontal_span {
   horizontal_span *next;
-  short start_col;
-  short end_col;
+  int start_col;
+  int end_col;
   horizontal_span(int, int, horizontal_span *);
 };
 
-struct single_line_entry;
-struct double_line_entry;
-struct simple_entry;
+class single_line_entry;
+class double_line_entry;
+class simple_entry;
 
 class table_entry {
 friend class table;
@@ -145,8 +145,8 @@ friend class table;
 protected:
   int start_row;
   int end_row;
-  short start_col;
-  short end_col;
+  int start_col;
+  int end_col;
   const entry_modifier *mod;
 public:
   void set_location();
@@ -687,8 +687,8 @@ void block_entry::do_divert(int alphabetic, int ncols, const string *mw,
   if (alphabetic)
     prints("-2n");
   prints("\n");
-  set_modifier(mod);
   prints(".cp \\n(" COMPATIBLE_REG "\n");
+  set_modifier(mod);
   set_location();
   prints(contents);
   prints(".br\n.di\n.cp 0\n");
@@ -965,6 +965,8 @@ void set_modifier(const entry_modifier *m)
       prints('-');
     printfs("%1\n", as_string(m->vertical_spacing.val));
   }
+  if (!m->macro.empty())
+    printfs(".%1\n", m->macro);
 }
 
 void set_inline_modifier(const entry_modifier *m)
@@ -1088,7 +1090,7 @@ struct vertical_rule {
   vertical_rule *next;
   int start_row;
   int end_row;
-  short col;
+  int col;
   char is_double;
   string top_adjust;
   string bot_adjust;
