@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002, 2004
    Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
@@ -41,7 +41,7 @@ void delete_request_or_macro(request_or_macro *);
 
 extern object_dictionary request_dictionary;
 
-struct macro_header;
+class macro_header;
 struct node;
 
 class macro : public request_or_macro {
